{ config, pkgs, ... }:

{
  environment.systemPackages = with pkgs.haskellPackages; with pkgs; [
    gitg
    gmpc
    m4
    subversion
    openjdk8
    sbt scala
    # firefoxWrapper
    # qutebrowser
    chromium
    # thunderbird
    qalculate-gtk
    speedcrunch
    viewnior
    gnupg
    pass xclip pwgen
    remmina
    ledger
    hledger
    hledger-diff
    cmake ninja
    mpv
    wireshark-gtk
    mutt
    goldendict
    patchelf
    bazaar
    tokei loc
    ripgrep
    imagemagick

    pdfpc

    # haskell dev
    cabal2nix
    cabal-install
    ghc-mod

    # emacs
    emacs
    emacsPackages.cask
    ghostscript # for auctex
    aspell

    nodejs

    mediainfo

    isync
    mu
    msmtp
    vdirsyncer khard khal

    config.boot.kernelPackages.perf

    veriT
    minisat
    picosat
    glucose
    prover9
    eprover
    metis-prover
    spass
    z3
    cvc4
    graphviz
    # toysolver
    stable.haskellPackages.tip-lib

    emacsPackages.proofgeneral

    stablePkgs # protect nixpkgs checkout from GC
  ] ++ (with aspellDicts; [ en de fr nl ]);

  nixpkgs.config.packageOverrides = pkgs: with pkgs; let
    fetchNixPkgs = { rev, sha256 }:
    fetchFromGitHub {
      inherit sha256 rev;
      owner = "NixOS";
      repo = "nixpkgs-channels";
    };
    stablePkgs = fetchNixPkgs {
      rev = "5237768d62a40236d24fafbd9f4f97f3227399ce";
      sha256 = "1j707pwm6ll2cvmqvwfxxq21gd9q7l6s3vi3vc01jklplj2v20is";
    };
  in {
    idea-community-eap = pkgs.idea.idea-community.overrideDerivation (oldAttrs: rec {
        name = "idea-community-${version}";
        version = "2017.1.eap";
        src = pkgs.fetchurl {
          url = "https://download.jetbrains.com/idea/ideaIC-171.3566.24-no-jdk.tar.gz";
          sha256 = "fae613cc8a39996aacd955cf10c7561984b17af15aa5565f8a3defff9a6b1930";
        };
      });

    clion-eap = pkgs.idea.clion.overrideDerivation (oldAttrs: rec {
      name = "clion-${version}";
      version = "2017.1.eap";
      src = pkgs.fetchurl {
        url = "http://download.jetbrains.com/cpp/CLion-171.3566.4.tar.gz";
        sha256 = "1vbaplj86gagbkh2sz8ydrbgx52rclanc08wggm48ri4a17aby2w";
      };
    });

    neovim = pkgs.neovim.override {
      extraPythonPackages = [ pkgs.pythonPackages.websocket_client ];
    };

    stablePkgs = stablePkgs;
    stable = import stablePkgs {};
  };

  nixpkgs.config.allowTexliveBuilds = true;
  nixpkgs.config.allowUnfree = true;

}
